@@ -1,9 +1,9 @@
 package Mail::Milter::Authentication::Handler::ARC;
 use strict;
 use warnings;
-use Mail::Milter::Authentication 2.20180903;
+use Mail::Milter::Authentication 2.20191205;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20181013'; # VERSION
+our $VERSION = '2.20191205'; # VERSION
 # ABSTRACT: Authentication Milter Module for validation of ARC signatures
 use Data::Dumper;
 use Clone qw{ clone };
@@ -448,14 +448,15 @@ sub envfrom_callback {
     $self->{'carry'}            = q{};
     $self->{'arc_auth_results'} = {};
     $self->{'arc_domain'}       = {};
+    $self->{'arc_result'}       = '';
     $self->destroy_object('arc');
     return;
 }
 
 sub header_callback {
-    my ( $self, $header, $value ) = @_;
+    my ( $self, $header, $value, $original ) = @_;
     my $EOL        = "\015\012";
-    my $arc_chunk = $header . ': ' . $value . $EOL;
+    my $arc_chunk = $original . $EOL;
     $arc_chunk =~ s/\015?\012/$EOL/g;
     push @{$self->{'headers'}} , $arc_chunk;
 
@@ -682,6 +683,7 @@ sub close_callback {
     delete $self->{'has_arc'};
     delete $self->{'valid_domains'};
     delete $self->{'arc_domain'};
+    delete $self->{'arc_result'};
     delete $self->{'arc_auth_results'};
     $self->destroy_object('arc');
     return;
@@ -856,7 +858,7 @@ Mail::Milter::Authentication::Handler::ARC - Authentication Milter Module for va
 
 =head1 VERSION
 
-version 2.20181013
+version 2.20191205
 
 =head1 DESCRIPTION
 
